@@ -6,10 +6,17 @@
 #' @param var1 The name (as a string) of the variable of interest in the interaction term; its conditional coefficient estimates will be plotted.
 #' @param var2 The name (as a string) of the other variable in the interaction term.
 #' @param plot A logical value indicating whether the output is a plot or a dataframe including the conditional coefficient estimates of var1, their upper and lower bounds, and the corresponding values of var2.
+#' @param hist A logical value indicating if there is a histogram of `var2` added at the bottom of the conditional effect plot.
+#' @param var2_dt A numerical value indicating the frequency distibution of `var2`. It is only used when `hist == TRUE`. When the object is a model, the default is the distribution of `var2` of the model. 
 #' @param point A logical value determining the format of plot. By default, the function produces a line plot when var2 takes on ten or more distinct values and a point (dot-and-whisker) plot otherwise; option TRUE forces a point plot.
 #' @param sims Number of independent simulation draws used to calculate upper and lower bounds of coefficient estimates: lower values run faster; higher values produce smoother curves.
 #' @param xmin A numerical value indicating the minimum value shown of x shown in the graph. Rarely used.
 #' @param xmax A numerical value indicating the maximum value shown of x shown in the graph. Rarely used.
+#' @param ercolor A character value indicating the outline color of the whisker or ribbon.
+#' @param esize A numerical value indicating the size of the whisker or ribbon.
+#' @param ralpha A numerical value indicating the transparency of the ribbon.
+#' @param rfill A character value indicating the filling color of the ribbon.
+#' @param ... Other ggplot aesthetics arguments for points in the dot-whisker plot or lines in the line-ribbon plots. Not currently used.
 #' 
 #' @details \code{interplot.mlm} is a S3 method from the \code{interplot}. It works on mixed-effects objects with class \code{lmerMod} and \code{glmerMod}.
 #' 
@@ -26,8 +33,8 @@
 #' @export
 
 # Coding function for non-mi mlm objects
-interplot.lmerMod <- function(m, var1, var2, plot = TRUE, point = FALSE, sims = 5000, 
-    xmin = NA, xmax = NA) {
+interplot.lmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt = NA, point = FALSE, sims = 5000, xmin = NA, 
+    xmax = NA, ercolor = NA, esize = 0.5, ralpha = 0.5, rfill = "grey70", ...) {
     set.seed(324)
     
     m.class <- class(m)
@@ -44,43 +51,37 @@ interplot.lmerMod <- function(m, var1, var2, plot = TRUE, point = FALSE, sims =
         var1_bk <- var1
         var1 <- paste0(var1, levels(eval(parse(text = paste0("m@frame$", var1)))))
         factor_v1 <- TRUE
-        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, 
-            ":", var1)[-1])
+        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, ":", var1)[-1])
         
         # the first category is censored to avoid multicolinarity
         for (i in seq(var12)) {
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
                 var12[i] <- paste0(var1, ":", var2)[-1][i]
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
-                stop(paste("Model does not include the interaction of", var1, "and", 
-                  var2, "."))
+                stop(paste("Model does not include the interaction of", var1, "and", var2, "."))
         }
     } else if (is.factor(eval(parse(text = paste0("m@frame$", var2))))) {
         var2_bk <- var2
         var2 <- paste0(var2, levels(eval(parse(text = paste0("m@frame$", var2)))))
         factor_v2 <- TRUE
-        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, 
-            ":", var1)[-1])
+        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, ":", var1)[-1])
         
         # the first category is censored to avoid multicolinarity
         for (i in seq(var12)) {
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
                 var12[i] <- paste0(var1, ":", var2)[-1][i]
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
-                stop(paste("Model does not include the interaction of", var1, "and", 
-                  var2, "."))
+                stop(paste("Model does not include the interaction of", var1, "and", var2, "."))
         }
     } else {
-        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, 
-            ":", var1))
+        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, ":", var1))
         
         # the first category is censored to avoid multicolinarity
         for (i in seq(var12)) {
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
                 var12[i] <- paste0(var1, ":", var2)[i]
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
-                stop(paste("Model does not include the interaction of", var1, "and", 
-                  var2, "."))
+                stop(paste("Model does not include the interaction of", var1, "and", var2, "."))
         }
     }
     
@@ -96,89 +97,101 @@ interplot.lmerMod <- function(m, var1, var2, plot = TRUE, point = FALSE, sims =
         if (is.na(xmax)) 
             xmax <- max(m@frame[var2], na.rm = T)
         
-        steps <- eval(parse(text = paste0("length(unique(na.omit(m@frame$", var2, 
-            ")))")))
+        steps <- eval(parse(text = paste0("length(unique(na.omit(m@frame$", var2, ")))")))
         if (steps > 100) 
             steps <- 100  # avoid redundant calculation
     }
     
-    coef <- data.frame(fake = seq(xmin, xmax, length.out = steps), coef1 = NA, 
-        ub = NA, lb = NA)
-    coef_df <- data.frame(fake = numeric(0), coef1 = numeric(0), ub = numeric(0), 
-        lb = numeric(0), model = character(0))
+    coef <- data.frame(fake = seq(xmin, xmax, length.out = steps), coef1 = NA, ub = NA, lb = NA)
+    coef_df <- data.frame(fake = numeric(0), coef1 = numeric(0), ub = numeric(0), lb = numeric(0), 
+        model = character(0))
     
     if (factor_v1) {
-        for (j in 1:(length(levels(eval(parse(text = paste0("m@frame$", var1_bk))))) - 
-            1)) {
+        for (j in 1:(length(levels(eval(parse(text = paste0("m@frame$", var1_bk))))) - 1)) {
             # only n - 1 interactions; one category is avoided against multicolinarity
             
             for (i in 1:steps) {
                 coef$coef1[i] <- mean(m.sims@fixef[, match(var1[j + 1], unlist(dimnames(m@pp$X)[2]))] + 
                   coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))])
                 coef$ub[i] <- quantile(m.sims@fixef[, match(var1[j + 1], unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 
-                  0.975)
+                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.975)
                 coef$lb[i] <- quantile(m.sims@fixef[, match(var1[j + 1], unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 
-                  0.025)
+                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.025)
             }
             
             if (plot == TRUE) {
                 coef$value <- var1[j + 1]
                 coef_df <- rbind(coef_df, coef)
+                if (hist == TRUE) {
+                  if (is.na(var2_dt)) {
+                    var2_dt <- eval(parse(text = paste0("m@frame$", var2)))
+                  } else {
+                    var2_dt <- var2_dt
+                  }
+                }
             } else {
                 names(coef) <- c(var2, "coef", "ub", "lb")
                 return(coef)
             }
         }
         coef_df$value <- as.factor(coef_df$value)
-        interplot.plot(m = coef_df, point = point) + facet_grid(. ~ value)
+        interplot.plot(m = coef_df, hist = hist, var2_dt = var2_dt, point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, ...) + facet_grid(. ~ value)
         
     } else if (factor_v2) {
-        for (j in 1:(length(levels(eval(parse(text = paste0("m@frame$", var2_bk))))) - 
-            1)) {
+        for (j in 1:(length(levels(eval(parse(text = paste0("m@frame$", var2_bk))))) - 1)) {
             # only n - 1 interactions; one category is avoided against multicolinarity
             
             for (i in 1:steps) {
                 coef$coef1[i] <- mean(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
                   coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))])
                 coef$ub[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 
-                  0.975)
+                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.975)
                 coef$lb[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 
-                  0.025)
+                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.025)
             }
             
             if (plot == TRUE) {
                 coef$value <- var2[j + 1]
                 coef_df <- rbind(coef_df, coef)
+                if (hist == TRUE) {
+                  if (is.na(var2_dt)) {
+                    var2_dt <- eval(parse(text = paste0("m@frame$", var2)))
+                  } else {
+                    var2_dt <- var2_dt
+                  }
+                }
             } else {
                 names(coef) <- c(var2, "coef", "ub", "lb")
                 return(coef)
             }
         }
         coef_df$value <- as.factor(coef_df$value)
-        interplot.plot(m = coef_df, point = point) + facet_grid(. ~ value)
+        interplot.plot(m = coef_df, hist = hist, var2_dt = var2_dt, point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, ...) + facet_grid(. ~ value)
         
         
     } else {
         ## Correct marginal effect for quadratic terms
-        multiplier <- if (var1 == var2) 2 else 1
-
+        multiplier <- if (var1 == var2) 
+            2 else 1
+        
         for (i in 1:steps) {
-            coef$coef1[i] <- mean(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
-                multiplier * coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))])
-            coef$ub[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
-                multiplier * coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))], 
-                0.975)
-            coef$lb[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
-                multiplier * coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))], 
-                0.025)
+            coef$coef1[i] <- mean(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + multiplier * 
+                coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))])
+            coef$ub[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + multiplier * 
+                coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))], 0.975)
+            coef$lb[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + multiplier * 
+                coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))], 0.025)
         }
         
         if (plot == TRUE) {
-            interplot.plot(m = coef, point = point)
+            if (hist == TRUE) {
+                if (is.na(var2_dt)) {
+                  var2_dt <- eval(parse(text = paste0("m@frame$", var2)))
+                } else {
+                  var2_dt <- var2_dt
+                }
+            }
+          interplot.plot(m = coef, hist = hist, var2_dt = var2_dt, point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, ...)
         } else {
             names(coef) <- c(var2, "coef", "ub", "lb")
             return(coef)
@@ -188,8 +201,7 @@ interplot.lmerMod <- function(m, var1, var2, plot = TRUE, point = FALSE, sims =
 }
 
 #' @export
-interplot.glmerMod <- function(m, var1, var2, plot = TRUE, point = FALSE, sims = 5000, 
-    xmin = NA, xmax = NA) {
+interplot.glmerMod <- function(m, var1, var2, plot = TRUE, hist = FALSE, var2_dt = NA, point = FALSE, sims = 5000, xmin = NA, xmax = NA, ercolor = NA, esize = 0.5, ralpha = 0.5, rfill = "grey70", ...) {
     set.seed(324)
     
     m.class <- class(m)
@@ -206,43 +218,37 @@ interplot.glmerMod <- function(m, var1, var2, plot = TRUE, point = FALSE, sims =
         var1_bk <- var1
         var1 <- paste0(var1, levels(eval(parse(text = paste0("m@frame$", var1)))))
         factor_v1 <- TRUE
-        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, 
-            ":", var1)[-1])
+        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, ":", var1)[-1])
         
         # the first category is censored to avoid multicolinarity
         for (i in seq(var12)) {
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
                 var12[i] <- paste0(var1, ":", var2)[-1][i]
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
-                stop(paste("Model does not include the interaction of", var1, "and", 
-                  var2, "."))
+                stop(paste("Model does not include the interaction of", var1, "and", var2, "."))
         }
     } else if (is.factor(eval(parse(text = paste0("m@frame$", var2))))) {
         var2_bk <- var2
         var2 <- paste0(var2, levels(eval(parse(text = paste0("m@frame$", var2)))))
         factor_v2 <- TRUE
-        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, 
-            ":", var1)[-1])
+        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, ":", var1)[-1])
         
         # the first category is censored to avoid multicolinarity
         for (i in seq(var12)) {
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
                 var12[i] <- paste0(var1, ":", var2)[-1][i]
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
-                stop(paste("Model does not include the interaction of", var1, "and", 
-                  var2, "."))
+                stop(paste("Model does not include the interaction of", var1, "and", var2, "."))
         }
     } else {
-        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, 
-            ":", var1))
+        ifelse(var1 == var2, var12 <- paste0("I(", var1, "^2)"), var12 <- paste0(var2, ":", var1))
         
         # the first category is censored to avoid multicolinarity
         for (i in seq(var12)) {
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
                 var12[i] <- paste0(var1, ":", var2)[i]
             if (!var12[i] %in% unlist(dimnames(m@pp$X)[2])) 
-                stop(paste("Model does not include the interaction of", var1, "and", 
-                  var2, "."))
+                stop(paste("Model does not include the interaction of", var1, "and", var2, "."))
         }
     }
     
@@ -258,89 +264,101 @@ interplot.glmerMod <- function(m, var1, var2, plot = TRUE, point = FALSE, sims =
         if (is.na(xmax)) 
             xmax <- max(m@frame[var2], na.rm = T)
         
-        steps <- eval(parse(text = paste0("length(unique(na.omit(m@frame$", var2, 
-            ")))")))
+        steps <- eval(parse(text = paste0("length(unique(na.omit(m@frame$", var2, ")))")))
         if (steps > 100) 
             steps <- 100  # avoid redundant calculation
     }
     
-    coef <- data.frame(fake = seq(xmin, xmax, length.out = steps), coef1 = NA, 
-        ub = NA, lb = NA)
-    coef_df <- data.frame(fake = numeric(0), coef1 = numeric(0), ub = numeric(0), 
-        lb = numeric(0), model = character(0))
+    coef <- data.frame(fake = seq(xmin, xmax, length.out = steps), coef1 = NA, ub = NA, lb = NA)
+    coef_df <- data.frame(fake = numeric(0), coef1 = numeric(0), ub = numeric(0), lb = numeric(0), 
+        model = character(0))
     
     if (factor_v1) {
-        for (j in 1:(length(levels(eval(parse(text = paste0("m@frame$", var1_bk))))) - 
-            1)) {
+        for (j in 1:(length(levels(eval(parse(text = paste0("m@frame$", var1_bk))))) - 1)) {
             # only n - 1 interactions; one category is avoided against multicolinarity
             
             for (i in 1:steps) {
                 coef$coef1[i] <- mean(m.sims@fixef[, match(var1[j + 1], unlist(dimnames(m@pp$X)[2]))] + 
                   coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))])
                 coef$ub[i] <- quantile(m.sims@fixef[, match(var1[j + 1], unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 
-                  0.975)
+                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.975)
                 coef$lb[i] <- quantile(m.sims@fixef[, match(var1[j + 1], unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 
-                  0.025)
+                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.025)
             }
             
             if (plot == TRUE) {
                 coef$value <- var1[j + 1]
                 coef_df <- rbind(coef_df, coef)
+                if (hist == TRUE) {
+                  if (is.na(var2_dt)) {
+                    var2_dt <- eval(parse(text = paste0("m@frame$", var2)))
+                  } else {
+                    var2_dt <- var2_dt
+                  }
+                }
             } else {
                 names(coef) <- c(var2, "coef", "ub", "lb")
                 return(coef)
             }
         }
         coef_df$value <- as.factor(coef_df$value)
-        interplot.plot(m = coef_df, point = point) + facet_grid(. ~ value)
+        interplot.plot(m = coef_df, hist = hist, var2_dt = var2_dt, point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, ...) + facet_grid(. ~ value)
         
     } else if (factor_v2) {
-        for (j in 1:(length(levels(eval(parse(text = paste0("m@frame$", var2_bk))))) - 
-            1)) {
+        for (j in 1:(length(levels(eval(parse(text = paste0("m@frame$", var2_bk))))) - 1)) {
             # only n - 1 interactions; one category is avoided against multicolinarity
             
             for (i in 1:steps) {
                 coef$coef1[i] <- mean(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
                   coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))])
                 coef$ub[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 
-                  0.975)
+                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.975)
                 coef$lb[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
-                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 
-                  0.025)
+                  coef$fake[i] * m.sims@fixef[, match(var12[j], unlist(dimnames(m@pp$X)[2]))], 0.025)
             }
             
             if (plot == TRUE) {
                 coef$value <- var2[j + 1]
                 coef_df <- rbind(coef_df, coef)
+                if (hist == TRUE) {
+                  if (is.na(var2_dt)) {
+                    var2_dt <- eval(parse(text = paste0("m@frame$", var2)))
+                  } else {
+                    var2_dt <- var2_dt
+                  }
+                }
             } else {
                 names(coef) <- c(var2, "coef", "ub", "lb")
                 return(coef)
             }
         }
         coef_df$value <- as.factor(coef_df$value)
-        interplot.plot(m = coef_df, point = point) + facet_grid(. ~ value)
+        interplot.plot(m = coef_df, hist = hist, var2_dt = var2_dt, point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, ...) + facet_grid(. ~ value)
         
         
     } else {
         ## Correct marginal effect for quadratic terms
-        multiplier <- if (var1 == var2) 2 else 1
-
+        multiplier <- if (var1 == var2) 
+            2 else 1
+        
         for (i in 1:steps) {
-            coef$coef1[i] <- mean(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
-                multiplier * coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))])
-            coef$ub[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
-                multiplier * coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))], 
-                0.975)
-            coef$lb[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + 
-                multiplier * coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))], 
-                0.025)
+            coef$coef1[i] <- mean(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + multiplier * 
+                coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))])
+            coef$ub[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + multiplier * 
+                coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))], 0.975)
+            coef$lb[i] <- quantile(m.sims@fixef[, match(var1, unlist(dimnames(m@pp$X)[2]))] + multiplier * 
+                coef$fake[i] * m.sims@fixef[, match(var12, unlist(dimnames(m@pp$X)[2]))], 0.025)
         }
         
         if (plot == TRUE) {
-            interplot.plot(m = coef, point = point)
+            if (hist == TRUE) {
+                if (is.na(var2_dt)) {
+                  var2_dt <- eval(parse(text = paste0("m@frame$", var2)))
+                } else {
+                  var2_dt <- var2_dt
+                }
+            }
+          interplot.plot(m = coef, hist = hist, var2_dt = var2_dt, point = point, ercolor = ercolor, esize = esize, ralpha = ralpha, rfill = rfill, ...)
         } else {
             names(coef) <- c(var2, "coef", "ub", "lb")
             return(coef)
